# Generated by Django 4.1.7 on 2024-04-09 10:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('gonk', '0003_alter_task_retry_time'),
    ]

    operations = [
        migrations.AddField(
            model_name='task',
            name='with_warnings',
            field=models.BooleanField(default=False),
        ),
    ]
